#' A physical map of the Iberian Peninsula
#' 
#' A tif image downloaded from http://www.openstreetmap.org/ using the R- library OpenStreetMap
#' 
#' @source http://www.openstreetmap.org/
#' @docType data
#' @keywords datasets
#' @format tif image
#' @name peninsula
NULL

#' A physical map of the Canary Islands
#' 
#' A tif image downloaded from http://www.openstreetmap.org/ using the R- library OpenStreetMap
#' 
#' @source http://www.openstreetmap.org/
#' @docType data
#' @keywords datasets
#' @format tif image
#' @name canarias
NULL

#' A Spanish administrative map
#' 
#' A shapefile downloaded from  http://www.diva-gis.org/
#' 
#' @source http://www.diva-gis.org/
#' @docType data
#' @keywords datasets
#' @format shapefile
#' @name ravis_shape_spain
NULL

#' UTM-Latlong 
#' 
#' Geographic coordinates (lat-long) of the centroids of the Spanish UTM squares
#' 
#' @docType data
#' @keywords datasets
#' @format matrix
#' @name ravisUTMLatLong
NULL

#' ravis_credentials
#'
#' Credentials for API
#'
#' @docType data
#' @keywords datasets
#' @format string
#' @name ravis_credentials
NULL
